@@ -17,7 +17,8 @@ $( document ).ready(function() {
       var page = $(this).attr('href').split('#p')[1];
       var item = $(this).attr('formbar-item');
       var itemid = $(this).attr('formbar-itemid');
-      $.get('/set_current_form_page', 
+      var baseurl = $(this).attr('formbar-baseurl');
+      $.get(baseurl+'/set_current_form_page', 
             {
                 page: page,
                 item: item,
@@ -30,7 +31,8 @@ $( document ).ready(function() {
       var page = $(this).attr('href').split('#p')[1];
       var item = $(this).attr('formbar-item');
       var itemid = $(this).attr('formbar-itemid');
-      $.get('/set_current_form_page', 
+      var baseurl = $(this).attr('formbar-baseurl');
+      $.get(baseurl+'/set_current_form_page', 
             {
                 page: page,
                 item: item,
