@@ -28,7 +28,7 @@ def set_current_form_page(request):
 def evaluate(request):
     """Will return a JSON response with the result of the evaluation of
     the submitted formbar rule."""
-    rule = Rule(expr=request.GET.get('rule').split(' '))
+    rule = Rule(request.GET.get('rule'))
     result = rule.evaluate({})
     return {"success": True,
             "data": result,
@@ -37,7 +37,7 @@ def evaluate(request):
 def example(request):
     config = Config(load(os.path.join(example_dir, 'example.xml')))
     form_config = config.get_form('example')
-    form = Form(form_config, eval_url="/evaluate")
+    form = Form(form_config, eval_url="/evaluate", request=request)
 
     if request.POST:
         form.validate(request.POST)
